@@ -67,6 +67,7 @@ OC.L10N.register(
     "Deck" : "Nástenka",
     "Changes in the <strong>Deck app</strong>" : "Zmeny v apke <strong>Nástenka</strong>",
     "A <strong>comment</strong> was created on a card" : "Na karte bol vytvorený <strong>komentár</strong>. ",
+    "Upcoming cards" : "Nadchádzajúce karty",
     "Personal" : "Osobné",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Používateľ %s vám priradil kartu „%s“ na „%s“.",
     "{user} has assigned the card \"%s\" on \"%s\" to you." : "Používateľ {user} vám priradil kartu „%s“ na „%s“.",
@@ -145,6 +146,8 @@ OC.L10N.register(
     "Undo" : "Odvolať",
     "Deleted cards" : "Odstránené karty",
     "Share board with a user, group or circle …" : "Zdieľanie nástenky s použivateľom, skupinou alebo okruhom…",
+    "Searching for users, groups and circles …" : "Vyhľadávanie v používateľoch, skupinách a kruhoch...",
+    "No participants found" : "Nenašli sa žiadni účastníci",
     "Board owner" : "Vlastník nástenky",
     "(Group)" : "(Skupina)",
     "(Circle)" : "(Okruh)",
@@ -152,25 +155,31 @@ OC.L10N.register(
     "Can share" : "Môže sprístupniť",
     "Can manage" : "Môže spravovať",
     "Delete" : "Zmazať",
+    "Failed to create share with {displayName}" : "Nepodarilo sa vytvoriť sprístupnenie pre {displayName}",
     "Add a new list" : "Pridať nový zoznam",
     "Archive all cards" : "Archivovať všetky karty",
     "Delete list" : "Vymazať zoznam",
     "Add card" : "Pridať kartu",
     "Archive all cards in this list" : "Archivovať všetky karty v tomto zozname",
     "Add a new card" : "Pridať novú kartu",
+    "Card name" : "Názov karty",
+    "List deleted" : "Zoznam bol vymazaný",
     "Edit" : "Upraviť",
     "Add a new tag" : "Pridať nový štítok",
     "title and color value must be provided" : "je potrebné zadať nadpis a vybrať farbu",
-    "Title" : "Názov",
+    "Board name" : "Názov nástenky",
     "Members" : "Členovia",
     "Upload attachment" : "Nahrať prílohu",
     "Add this attachment" : "Pridať túto prílohu",
     "Delete Attachment" : "Odstrániť prílohu",
     "Restore Attachment" : "Obnoviť prílohu",
+    "Open in sidebar view" : "Otvoriť v zobrazení v bočnom paneli",
+    "Open in bigger view" : "Otvoriť vo väčšom zobrazení",
     "Attachments" : "Prílohy",
     "Comments" : "Komentáre",
     "Modified" : "Upravené",
     "Created" : "Vytvorené",
+    "The title cannot be empty." : "Nadpis nemôže byť prázdny.",
     "No comments yet. Begin the discussion!" : "Zatiaľ bez komentárov. Začnite diskusiu!",
     "Assign a tag to this card…" : "Tejto karte priradiť štítok…",
     "Assign to users" : "Priradiť používateľom",
@@ -193,6 +202,7 @@ OC.L10N.register(
     "Edit description" : "Upraviť popis",
     "View description" : "Zobraziť popis",
     "Add Attachment" : "Pridať prílohu",
+    "Write a description …" : "Napíšte popis...",
     "Choose attachment" : "Vybrať prílohu",
     "(group)" : "(skupina)",
     "(circle)" : "(okruh)",
@@ -204,21 +214,39 @@ OC.L10N.register(
     "Delete card" : "Zmazať kartu",
     "Move card to another board" : "Presunúť kartu na inú nástenku",
     "Select a list" : "Vybrať zoznam",
+    "Card deleted" : "Karta bola vymazaná",
     "seconds ago" : "pred niekoľkými sekundami",
     "All boards" : "Všetky nástenky",
     "Archived boards" : "Archivované nástenky",
     "Shared with you" : "Vám sprístupnené",
+    "Show boards in calendar/tasks" : "Zobrazovať nástenky v kalendári/úlohách",
     "Limit deck usage of groups" : "Obmedziť použitie Deck na skupiny",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Obmedzenie Násteniek bráni používateľom, ktorí nie sú súčasťou týchto skupín, aby si vytvárali vlastné nástenky. Môžu však stále pracovať na nástenkách, ktoré im niekto sprístupní.",
     "Board details" : "Podrobnosti o nástenke",
     "Edit board" : "Upraviť nástenku",
+    "Clone board" : "Duplikovať nástenku",
+    "Unarchive board" : "Zrušiť archiváciu nástenky",
+    "Archive board" : "Archivovať nástenku",
+    "Turn on due date reminders" : "Zapnúť pripomienky na termín dokončenia",
+    "Turn off due date reminders" : "Vypnúť pripomienky na termín dokončenia",
+    "Due date reminders" : "Pripomienky termínu dokončenia",
+    "All cards" : "Všetky karty",
+    "Assigned cards" : "Priradené karty",
+    "No notifications" : "Žiadne upozornenia",
+    "Delete board" : "Vymazať nástenku",
     "Board {0} deleted" : "Nástenka {0} vymazaná",
+    "Only assigned cards" : "Len priradené karty",
+    "No reminder" : "Žiadna pripomienka",
     "An error occurred" : "Vyskytla sa chyba",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Naozaj chcete chcete vymazať nástenku {title}? Toto zmaže všetky údaje o tejto nástenke.",
     "Delete the board?" : "Vymazať nástenku?",
+    "Loading filtered view" : "Načítavanie filtrovaného pohľadu",
     "Today" : "Dnes",
     "Tomorrow" : "Zajtra",
     "This week" : "Tento týždeň",
+    "No due" : "Žiadny termín dokončenia",
+    "No upcoming cards" : "Žiadne nadchádzajúce karty",
+    "upcoming cards" : "nadchádzajúce karty",
     "Link to a board" : "Odkaz na nástenku",
     "Link to a card" : "Prepojiť s kartou",
     "Something went wrong" : "Niečo sa pokazilo",
