@@ -167,7 +167,7 @@ OC.L10N.register(
     "Edit" : "Uredi",
     "Add a new tag" : "Dodaj novo oznako",
     "title and color value must be provided" : "navedena morata biti podatka naslova in barve",
-    "Title" : "Naslov",
+    "Board name" : "Ime  zbirke",
     "Members" : "Člani",
     "Upload attachment" : "Pošlji prilogo",
     "Add this attachment" : "Dodaj prilogo",
@@ -219,16 +219,17 @@ OC.L10N.register(
     "All boards" : "Vse zbirke",
     "Archived boards" : "Arhivirane zbirke",
     "Shared with you" : "V souporabi z vami",
-    "Use modal card view" : "Uporabi modalni pogled nalog",
     "Show boards in calendar/tasks" : "Pokaži zbirke v koledarjem in med opravili",
     "Limit deck usage of groups" : "Omeji uporabo zbirk na skupine",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omejevanje programa prepreči uporabnikom, ki niso del teh skupin, ustvarjanje novih zbirk. Uporabniki bodo še vedno lahko spreminjali zbirke, ki so jih dobili v souporabo.",
-    "Board name" : "Ime  zbirke",
     "Board details" : "Podrobnosti zbirke",
     "Edit board" : "Uredi zbirko",
     "Clone board" : "Kloniraj zbirko",
     "Unarchive board" : "Povrni zbirko",
     "Archive board" : "Arhiviraj zbirko",
+    "Turn on due date reminders" : "Omogoči opomnike o datumu zapadlosti ",
+    "Turn off due date reminders" : "Onemogoči opomnike o datumu zapadlosti",
+    "Due date reminders" : "Opomniki o datumu zapadlosti",
     "All cards" : "Vse naloge",
     "Assigned cards" : "Dodeljene naloge",
     "No notifications" : "Ni obvestil",
@@ -249,6 +250,7 @@ OC.L10N.register(
     "Link to a board" : "Povezava do zbirke",
     "Link to a card" : "Povezava do naloge",
     "Something went wrong" : "Prišlo je do napake ...",
+    "Failed to upload {name}" : "Pošiljanje {name} je spodletelo",
     "Maximum file size of {size} exceeded" : "Omejitev velikosti datoteke {size} je prekoračena."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
