@@ -25,7 +25,6 @@
 
 namespace OCA\Deck\Activity;
 
-use cogpowered\FineDiff\Diff;
 use OCA\Deck\Db\Acl;
 use OCP\Activity\IEvent;
 use OCP\Activity\IProvider;
@@ -290,7 +289,7 @@ class DeckProvider implements IProvider {
 			try {
 				$comment = $this->commentsManager->get((int)$subjectParams['comment']);
 				$event->setParsedMessage($comment->getMessage());
-				$params['comment'] =[
+				$params['comment'] = [
 					'type' => 'highlight',
 					'id' => $subjectParams['comment'],
 					'name' => $comment->getMessage()
@@ -326,11 +325,9 @@ class DeckProvider implements IProvider {
 	 * @return mixed
 	 */
 	private function parseParamForChanges($subjectParams, $params, $event) {
-		if (array_key_exists('diff', $subjectParams) && $subjectParams['diff']) {
-			$diff = new Diff();
+		if (array_key_exists('diff', $subjectParams) && $subjectParams['diff'] && !empty($subjectParams['after'])) {
 			// Don't add diff as message since we are limited to 255 chars here
 			$event->setParsedMessage($subjectParams['after']);
-			//$event->setParsedMessage('<pre class="visualdiff">' . $diff->render($subjectParams['before'], $subjectParams['after']) . '</pre>');
 			return $params;
 		}
 		if (array_key_exists('before', $subjectParams)) {
